package com.ruoyi.project.plant.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TMtdConfigMapper;
import com.ruoyi.project.plant.domain.TMtdConfig;
import com.ruoyi.project.plant.service.ITMtdConfigService;

/**
 * 调度会议配置Service业务层处理
 *
 * @author ssy
 * @date 2023-11-16
 */
@Service
public class TMtdConfigServiceImpl implements ITMtdConfigService
{
    @Autowired
    private TMtdConfigMapper tMtdConfigMapper;

    /**
     * 查询调度会议配置
     *
     * @param id 调度会议配置ID
     * @return 调度会议配置
     */
    @Override
    public TMtdConfig selectTMtdConfigById(Long id)
    {
        return tMtdConfigMapper.selectTMtdConfigById(id);
    }

    /**
     * 查询调度会议配置列表
     *
     * @param tMtdConfig 调度会议配置
     * @return 调度会议配置
     */
    @Override
    public List<TMtdConfig> selectTMtdConfigList(TMtdConfig tMtdConfig)
    {
        return tMtdConfigMapper.selectTMtdConfigList(tMtdConfig);
    }

    /**
     * 新增调度会议配置
     *
     * @param tMtdConfig 调度会议配置
     * @return 结果
     */
    @Override
    public int insertTMtdConfig(TMtdConfig tMtdConfig)
    {
        tMtdConfig.setCreateTime(DateUtils.getNowDate());
        return tMtdConfigMapper.insertTMtdConfig(tMtdConfig);
    }

    /**
     * 修改调度会议配置
     *
     * @param tMtdConfig 调度会议配置
     * @return 结果
     */
    @Override
    public int updateTMtdConfig(TMtdConfig tMtdConfig)
    {
        tMtdConfig.setUpdateTime(DateUtils.getNowDate());
        return tMtdConfigMapper.updateTMtdConfig(tMtdConfig);
    }

    /**
     * 批量删除调度会议配置
     *
     * @param ids 需要删除的调度会议配置ID
     * @return 结果
     */
    @Override
    public int deleteTMtdConfigByIds(Long[] ids)
    {
        return tMtdConfigMapper.deleteTMtdConfigByIds(ids);
    }

    /**
     * 删除调度会议配置信息
     *
     * @param id 调度会议配置ID
     * @return 结果
     */
    @Override
    public int deleteTMtdConfigById(Long id)
    {
        return tMtdConfigMapper.deleteTMtdConfigById(id);
    }
}
